# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/variables.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/variables.proto',
  package='angr.protos',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16protos/variables.proto\x12\x0b\x61ngr.protos\"\x80\x01\n\x0cVariableBase\x12\r\n\x05ident\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x06region\x18\x03 \x01(\x04H\x00\x88\x01\x01\x12\x15\n\x08\x63\x61tegory\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x0f\n\x07renamed\x18\x05 \x01(\x08\x42\t\n\x07_regionB\x0b\n\t_category\"L\n\x11TemporaryVariable\x12\'\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x19.angr.protos.VariableBase\x12\x0e\n\x06tmp_id\x18\x02 \x01(\r\"V\n\x10RegisterVariable\x12\'\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x19.angr.protos.VariableBase\x12\x0b\n\x03reg\x18\x02 \x01(\r\x12\x0c\n\x04size\x18\x03 \x01(\r\"U\n\x0eMemoryVariable\x12\'\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x19.angr.protos.VariableBase\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\"u\n\rStackVariable\x12\'\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x19.angr.protos.VariableBase\x12\x0c\n\x04\x61\x64\x64r\x18\x02 \x01(\x04\x12\x0c\n\x04size\x18\x03 \x01(\r\x12\x0f\n\x07sp_base\x18\x04 \x01(\x08\x12\x0e\n\x06offset\x18\x05 \x01(\x05\"\x9c\x02\n\x0eVariableAccess\x12\r\n\x05ident\x18\x01 \x01(\t\x12\x12\n\nblock_addr\x18\x02 \x01(\x04\x12\x10\n\x08stmt_idx\x18\x03 \x01(\x05\x12\x10\n\x08ins_addr\x18\x04 \x01(\x04\x12\x13\n\x06offset\x18\x05 \x01(\x03H\x00\x88\x01\x01\x12\x43\n\x0b\x61\x63\x63\x65ss_type\x18\x06 \x01(\x0e\x32..angr.protos.VariableAccess.VariableAccessSort\x12\x16\n\tatom_hash\x18\x07 \x01(\rH\x01\x88\x01\x01\"8\n\x12VariableAccessSort\x12\t\n\x05WRITE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\r\n\tREFERENCE\x10\x02\x42\t\n\x07_offsetB\x0c\n\n_atom_hash\"/\n\x0cVariableType\x12\r\n\x05ident\x18\x01 \x01(\t\x12\x10\n\x08var_type\x18\x02 \x01(\t\";\n\x0bVar2Unified\x12\x11\n\tvar_ident\x18\x01 \x01(\t\x12\x19\n\x11unified_var_ident\x18\x02 \x01(\t\"\xbf\x04\n\x17VariableManagerInternal\x12\x30\n\x08tempvars\x18\x01 \x03(\x0b\x32\x1e.angr.protos.TemporaryVariable\x12.\n\x07regvars\x18\x02 \x03(\x0b\x32\x1d.angr.protos.RegisterVariable\x12,\n\x07memvars\x18\x03 \x03(\x0b\x32\x1b.angr.protos.MemoryVariable\x12-\n\tstackvars\x18\x04 \x03(\x0b\x32\x1a.angr.protos.StackVariable\x12-\n\x08\x61\x63\x63\x65sses\x18\x05 \x03(\x0b\x32\x1b.angr.protos.VariableAccess\x12\x38\n\x10unified_tempvars\x18\x06 \x03(\x0b\x32\x1e.angr.protos.TemporaryVariable\x12\x36\n\x0funified_regvars\x18\x07 \x03(\x0b\x32\x1d.angr.protos.RegisterVariable\x12\x34\n\x0funified_memvars\x18\x08 \x03(\x0b\x32\x1b.angr.protos.MemoryVariable\x12\x35\n\x11unified_stackvars\x18\t \x03(\x0b\x32\x1a.angr.protos.StackVariable\x12-\n\x0bvar2unified\x18\n \x03(\x0b\x32\x18.angr.protos.Var2Unified\x12(\n\x05types\x18\x0b \x03(\x0b\x32\x19.angr.protos.VariableTypeb\x06proto3'
)



_VARIABLEACCESS_VARIABLEACCESSSORT = _descriptor.EnumDescriptor(
  name='VariableAccessSort',
  full_name='angr.protos.VariableAccess.VariableAccessSort',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REFERENCE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=746,
  serialized_end=802,
)
_sym_db.RegisterEnumDescriptor(_VARIABLEACCESS_VARIABLEACCESSSORT)


_VARIABLEBASE = _descriptor.Descriptor(
  name='VariableBase',
  full_name='angr.protos.VariableBase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ident', full_name='angr.protos.VariableBase.ident', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='angr.protos.VariableBase.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='angr.protos.VariableBase.region', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='angr.protos.VariableBase.category', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='renamed', full_name='angr.protos.VariableBase.renamed', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_region', full_name='angr.protos.VariableBase._region',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_category', full_name='angr.protos.VariableBase._category',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=40,
  serialized_end=168,
)


_TEMPORARYVARIABLE = _descriptor.Descriptor(
  name='TemporaryVariable',
  full_name='angr.protos.TemporaryVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='angr.protos.TemporaryVariable.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tmp_id', full_name='angr.protos.TemporaryVariable.tmp_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=246,
)


_REGISTERVARIABLE = _descriptor.Descriptor(
  name='RegisterVariable',
  full_name='angr.protos.RegisterVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='angr.protos.RegisterVariable.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reg', full_name='angr.protos.RegisterVariable.reg', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='angr.protos.RegisterVariable.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=248,
  serialized_end=334,
)


_MEMORYVARIABLE = _descriptor.Descriptor(
  name='MemoryVariable',
  full_name='angr.protos.MemoryVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='angr.protos.MemoryVariable.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='angr.protos.MemoryVariable.addr', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='angr.protos.MemoryVariable.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=421,
)


_STACKVARIABLE = _descriptor.Descriptor(
  name='StackVariable',
  full_name='angr.protos.StackVariable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='angr.protos.StackVariable.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addr', full_name='angr.protos.StackVariable.addr', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='angr.protos.StackVariable.size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sp_base', full_name='angr.protos.StackVariable.sp_base', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='angr.protos.StackVariable.offset', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=423,
  serialized_end=540,
)


_VARIABLEACCESS = _descriptor.Descriptor(
  name='VariableAccess',
  full_name='angr.protos.VariableAccess',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ident', full_name='angr.protos.VariableAccess.ident', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_addr', full_name='angr.protos.VariableAccess.block_addr', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stmt_idx', full_name='angr.protos.VariableAccess.stmt_idx', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ins_addr', full_name='angr.protos.VariableAccess.ins_addr', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='angr.protos.VariableAccess.offset', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='access_type', full_name='angr.protos.VariableAccess.access_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='atom_hash', full_name='angr.protos.VariableAccess.atom_hash', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VARIABLEACCESS_VARIABLEACCESSSORT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='_offset', full_name='angr.protos.VariableAccess._offset',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
    _descriptor.OneofDescriptor(
      name='_atom_hash', full_name='angr.protos.VariableAccess._atom_hash',
      index=1, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=543,
  serialized_end=827,
)


_VARIABLETYPE = _descriptor.Descriptor(
  name='VariableType',
  full_name='angr.protos.VariableType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ident', full_name='angr.protos.VariableType.ident', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='var_type', full_name='angr.protos.VariableType.var_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=829,
  serialized_end=876,
)


_VAR2UNIFIED = _descriptor.Descriptor(
  name='Var2Unified',
  full_name='angr.protos.Var2Unified',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='var_ident', full_name='angr.protos.Var2Unified.var_ident', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unified_var_ident', full_name='angr.protos.Var2Unified.unified_var_ident', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=878,
  serialized_end=937,
)


_VARIABLEMANAGERINTERNAL = _descriptor.Descriptor(
  name='VariableManagerInternal',
  full_name='angr.protos.VariableManagerInternal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tempvars', full_name='angr.protos.VariableManagerInternal.tempvars', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='regvars', full_name='angr.protos.VariableManagerInternal.regvars', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memvars', full_name='angr.protos.VariableManagerInternal.memvars', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stackvars', full_name='angr.protos.VariableManagerInternal.stackvars', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accesses', full_name='angr.protos.VariableManagerInternal.accesses', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unified_tempvars', full_name='angr.protos.VariableManagerInternal.unified_tempvars', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unified_regvars', full_name='angr.protos.VariableManagerInternal.unified_regvars', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unified_memvars', full_name='angr.protos.VariableManagerInternal.unified_memvars', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unified_stackvars', full_name='angr.protos.VariableManagerInternal.unified_stackvars', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='var2unified', full_name='angr.protos.VariableManagerInternal.var2unified', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types', full_name='angr.protos.VariableManagerInternal.types', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1515,
)

_VARIABLEBASE.oneofs_by_name['_region'].fields.append(
  _VARIABLEBASE.fields_by_name['region'])
_VARIABLEBASE.fields_by_name['region'].containing_oneof = _VARIABLEBASE.oneofs_by_name['_region']
_VARIABLEBASE.oneofs_by_name['_category'].fields.append(
  _VARIABLEBASE.fields_by_name['category'])
_VARIABLEBASE.fields_by_name['category'].containing_oneof = _VARIABLEBASE.oneofs_by_name['_category']
_TEMPORARYVARIABLE.fields_by_name['base'].message_type = _VARIABLEBASE
_REGISTERVARIABLE.fields_by_name['base'].message_type = _VARIABLEBASE
_MEMORYVARIABLE.fields_by_name['base'].message_type = _VARIABLEBASE
_STACKVARIABLE.fields_by_name['base'].message_type = _VARIABLEBASE
_VARIABLEACCESS.fields_by_name['access_type'].enum_type = _VARIABLEACCESS_VARIABLEACCESSSORT
_VARIABLEACCESS_VARIABLEACCESSSORT.containing_type = _VARIABLEACCESS
_VARIABLEACCESS.oneofs_by_name['_offset'].fields.append(
  _VARIABLEACCESS.fields_by_name['offset'])
_VARIABLEACCESS.fields_by_name['offset'].containing_oneof = _VARIABLEACCESS.oneofs_by_name['_offset']
_VARIABLEACCESS.oneofs_by_name['_atom_hash'].fields.append(
  _VARIABLEACCESS.fields_by_name['atom_hash'])
_VARIABLEACCESS.fields_by_name['atom_hash'].containing_oneof = _VARIABLEACCESS.oneofs_by_name['_atom_hash']
_VARIABLEMANAGERINTERNAL.fields_by_name['tempvars'].message_type = _TEMPORARYVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['regvars'].message_type = _REGISTERVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['memvars'].message_type = _MEMORYVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['stackvars'].message_type = _STACKVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['accesses'].message_type = _VARIABLEACCESS
_VARIABLEMANAGERINTERNAL.fields_by_name['unified_tempvars'].message_type = _TEMPORARYVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['unified_regvars'].message_type = _REGISTERVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['unified_memvars'].message_type = _MEMORYVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['unified_stackvars'].message_type = _STACKVARIABLE
_VARIABLEMANAGERINTERNAL.fields_by_name['var2unified'].message_type = _VAR2UNIFIED
_VARIABLEMANAGERINTERNAL.fields_by_name['types'].message_type = _VARIABLETYPE
DESCRIPTOR.message_types_by_name['VariableBase'] = _VARIABLEBASE
DESCRIPTOR.message_types_by_name['TemporaryVariable'] = _TEMPORARYVARIABLE
DESCRIPTOR.message_types_by_name['RegisterVariable'] = _REGISTERVARIABLE
DESCRIPTOR.message_types_by_name['MemoryVariable'] = _MEMORYVARIABLE
DESCRIPTOR.message_types_by_name['StackVariable'] = _STACKVARIABLE
DESCRIPTOR.message_types_by_name['VariableAccess'] = _VARIABLEACCESS
DESCRIPTOR.message_types_by_name['VariableType'] = _VARIABLETYPE
DESCRIPTOR.message_types_by_name['Var2Unified'] = _VAR2UNIFIED
DESCRIPTOR.message_types_by_name['VariableManagerInternal'] = _VARIABLEMANAGERINTERNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VariableBase = _reflection.GeneratedProtocolMessageType('VariableBase', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLEBASE,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.VariableBase)
  })
_sym_db.RegisterMessage(VariableBase)

TemporaryVariable = _reflection.GeneratedProtocolMessageType('TemporaryVariable', (_message.Message,), {
  'DESCRIPTOR' : _TEMPORARYVARIABLE,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.TemporaryVariable)
  })
_sym_db.RegisterMessage(TemporaryVariable)

RegisterVariable = _reflection.GeneratedProtocolMessageType('RegisterVariable', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERVARIABLE,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.RegisterVariable)
  })
_sym_db.RegisterMessage(RegisterVariable)

MemoryVariable = _reflection.GeneratedProtocolMessageType('MemoryVariable', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYVARIABLE,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.MemoryVariable)
  })
_sym_db.RegisterMessage(MemoryVariable)

StackVariable = _reflection.GeneratedProtocolMessageType('StackVariable', (_message.Message,), {
  'DESCRIPTOR' : _STACKVARIABLE,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.StackVariable)
  })
_sym_db.RegisterMessage(StackVariable)

VariableAccess = _reflection.GeneratedProtocolMessageType('VariableAccess', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLEACCESS,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.VariableAccess)
  })
_sym_db.RegisterMessage(VariableAccess)

VariableType = _reflection.GeneratedProtocolMessageType('VariableType', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLETYPE,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.VariableType)
  })
_sym_db.RegisterMessage(VariableType)

Var2Unified = _reflection.GeneratedProtocolMessageType('Var2Unified', (_message.Message,), {
  'DESCRIPTOR' : _VAR2UNIFIED,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.Var2Unified)
  })
_sym_db.RegisterMessage(Var2Unified)

VariableManagerInternal = _reflection.GeneratedProtocolMessageType('VariableManagerInternal', (_message.Message,), {
  'DESCRIPTOR' : _VARIABLEMANAGERINTERNAL,
  '__module__' : 'protos.variables_pb2'
  # @@protoc_insertion_point(class_scope:angr.protos.VariableManagerInternal)
  })
_sym_db.RegisterMessage(VariableManagerInternal)


# @@protoc_insertion_point(module_scope)



# pylint:disable=line-too-long
import logging

from ...sim_type import SimTypeFunction,     SimTypeShort, SimTypeInt, SimTypeLong, SimTypeLongLong, SimTypeDouble, SimTypeFloat,     SimTypePointer,     SimTypeChar,     SimStruct,     SimTypeFixedSizeArray,     SimTypeBottom,     SimUnion,     SimTypeBool
from ...calling_conventions import SimCCStdcall, SimCCMicrosoftAMD64
from .. import SIM_PROCEDURES as P
from . import SimLibrary


_l = logging.getLogger(name=__name__)


lib = SimLibrary()
lib.set_default_cc('X86', SimCCStdcall)
lib.set_default_cc('AMD64', SimCCMicrosoftAMD64)
lib.set_library_names("dwmapi.dll")
prototypes = \
    {
        # 
        'DwmDefWindowProc': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt"), label="UIntPtr", offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hWnd", "msg", "wParam", "lParam", "plResult"]),
        # 
        'DwmEnableBlurBehindWindow': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"dwFlags": SimTypeInt(signed=False, label="UInt32"), "fEnable": SimTypeInt(signed=True, label="Int32"), "hRgnBlur": SimTypeBottom(label="HRGN"), "fTransitionOnMaximized": SimTypeInt(signed=True, label="Int32")}, name="DWM_BLURBEHIND", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hWnd", "pBlurBehind"]),
        # 
        'DwmEnableComposition': SimTypeFunction([SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["uCompositionAction"]),
        # 
        'DwmEnableMMCSS': SimTypeFunction([SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["fEnableMMCSS"]),
        # 
        'DwmExtendFrameIntoClientArea': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"cxLeftWidth": SimTypeInt(signed=True, label="Int32"), "cxRightWidth": SimTypeInt(signed=True, label="Int32"), "cyTopHeight": SimTypeInt(signed=True, label="Int32"), "cyBottomHeight": SimTypeInt(signed=True, label="Int32")}, name="MARGINS", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hWnd", "pMarInset"]),
        # 
        'DwmGetColorizationColor': SimTypeFunction([SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pcrColorization", "pfOpaqueBlend"]),
        # 
        'DwmGetCompositionTimingInfo': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"cbSize": SimTypeInt(signed=False, label="UInt32"), "rateRefresh": SimStruct({"uiNumerator": SimTypeInt(signed=False, label="UInt32"), "uiDenominator": SimTypeInt(signed=False, label="UInt32")}, name="UNSIGNED_RATIO", pack=False, align=None), "qpcRefreshPeriod": SimTypeLongLong(signed=False, label="UInt64"), "rateCompose": SimStruct({"uiNumerator": SimTypeInt(signed=False, label="UInt32"), "uiDenominator": SimTypeInt(signed=False, label="UInt32")}, name="UNSIGNED_RATIO", pack=False, align=None), "qpcVBlank": SimTypeLongLong(signed=False, label="UInt64"), "cRefresh": SimTypeLongLong(signed=False, label="UInt64"), "cDXRefresh": SimTypeInt(signed=False, label="UInt32"), "qpcCompose": SimTypeLongLong(signed=False, label="UInt64"), "cFrame": SimTypeLongLong(signed=False, label="UInt64"), "cDXPresent": SimTypeInt(signed=False, label="UInt32"), "cRefreshFrame": SimTypeLongLong(signed=False, label="UInt64"), "cFrameSubmitted": SimTypeLongLong(signed=False, label="UInt64"), "cDXPresentSubmitted": SimTypeInt(signed=False, label="UInt32"), "cFrameConfirmed": SimTypeLongLong(signed=False, label="UInt64"), "cDXPresentConfirmed": SimTypeInt(signed=False, label="UInt32"), "cRefreshConfirmed": SimTypeLongLong(signed=False, label="UInt64"), "cDXRefreshConfirmed": SimTypeInt(signed=False, label="UInt32"), "cFramesLate": SimTypeLongLong(signed=False, label="UInt64"), "cFramesOutstanding": SimTypeInt(signed=False, label="UInt32"), "cFrameDisplayed": SimTypeLongLong(signed=False, label="UInt64"), "qpcFrameDisplayed": SimTypeLongLong(signed=False, label="UInt64"), "cRefreshFrameDisplayed": SimTypeLongLong(signed=False, label="UInt64"), "cFrameComplete": SimTypeLongLong(signed=False, label="UInt64"), "qpcFrameComplete": SimTypeLongLong(signed=False, label="UInt64"), "cFramePending": SimTypeLongLong(signed=False, label="UInt64"), "qpcFramePending": SimTypeLongLong(signed=False, label="UInt64"), "cFramesDisplayed": SimTypeLongLong(signed=False, label="UInt64"), "cFramesComplete": SimTypeLongLong(signed=False, label="UInt64"), "cFramesPending": SimTypeLongLong(signed=False, label="UInt64"), "cFramesAvailable": SimTypeLongLong(signed=False, label="UInt64"), "cFramesDropped": SimTypeLongLong(signed=False, label="UInt64"), "cFramesMissed": SimTypeLongLong(signed=False, label="UInt64"), "cRefreshNextDisplayed": SimTypeLongLong(signed=False, label="UInt64"), "cRefreshNextPresented": SimTypeLongLong(signed=False, label="UInt64"), "cRefreshesDisplayed": SimTypeLongLong(signed=False, label="UInt64"), "cRefreshesPresented": SimTypeLongLong(signed=False, label="UInt64"), "cRefreshStarted": SimTypeLongLong(signed=False, label="UInt64"), "cPixelsReceived": SimTypeLongLong(signed=False, label="UInt64"), "cPixelsDrawn": SimTypeLongLong(signed=False, label="UInt64"), "cBuffersEmpty": SimTypeLongLong(signed=False, label="UInt64")}, name="DWM_TIMING_INFO", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "pTimingInfo"]),
        # 
        'DwmGetWindowAttribute': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="DWMWINDOWATTRIBUTE"), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "dwAttribute", "pvAttribute", "cbAttribute"]),
        # 
        'DwmIsCompositionEnabled': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pfEnabled"]),
        # 
        'DwmModifyPreviousDxFrameDuration': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=True, label="Int32"), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "cRefreshes", "fRelative"]),
        # 
        'DwmQueryThumbnailSourceSize': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"cx": SimTypeInt(signed=True, label="Int32"), "cy": SimTypeInt(signed=True, label="Int32")}, name="SIZE", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hThumbnail", "pSize"]),
        # 
        'DwmRegisterThumbnail': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hwndDestination", "hwndSource", "phThumbnailId"]),
        # 
        'DwmSetDxFrameDuration': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "cRefreshes"]),
        # 
        'DwmSetPresentParameters': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"cbSize": SimTypeInt(signed=False, label="UInt32"), "fQueue": SimTypeInt(signed=True, label="Int32"), "cRefreshStart": SimTypeLongLong(signed=False, label="UInt64"), "cBuffer": SimTypeInt(signed=False, label="UInt32"), "fUseSourceRate": SimTypeInt(signed=True, label="Int32"), "rateSource": SimStruct({"uiNumerator": SimTypeInt(signed=False, label="UInt32"), "uiDenominator": SimTypeInt(signed=False, label="UInt32")}, name="UNSIGNED_RATIO", pack=False, align=None), "cRefreshesPerFrame": SimTypeInt(signed=False, label="UInt32"), "eSampling": SimTypeInt(signed=False, label="DWM_SOURCE_FRAME_SAMPLING")}, name="DWM_PRESENT_PARAMETERS", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "pPresentParams"]),
        # 
        'DwmSetWindowAttribute': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="DWMWINDOWATTRIBUTE"), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "dwAttribute", "pvAttribute", "cbAttribute"]),
        # 
        'DwmUnregisterThumbnail': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hThumbnailId"]),
        # 
        'DwmUpdateThumbnailProperties': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"dwFlags": SimTypeInt(signed=False, label="UInt32"), "rcDestination": SimStruct({"left": SimTypeInt(signed=True, label="Int32"), "top": SimTypeInt(signed=True, label="Int32"), "right": SimTypeInt(signed=True, label="Int32"), "bottom": SimTypeInt(signed=True, label="Int32")}, name="RECT", pack=False, align=None), "rcSource": SimStruct({"left": SimTypeInt(signed=True, label="Int32"), "top": SimTypeInt(signed=True, label="Int32"), "right": SimTypeInt(signed=True, label="Int32"), "bottom": SimTypeInt(signed=True, label="Int32")}, name="RECT", pack=False, align=None), "opacity": SimTypeChar(label="Byte"), "fVisible": SimTypeInt(signed=True, label="Int32"), "fSourceClientAreaOnly": SimTypeInt(signed=True, label="Int32")}, name="DWM_THUMBNAIL_PROPERTIES", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hThumbnailId", "ptnProperties"]),
        # 
        'DwmSetIconicThumbnail': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "hbmp", "dwSITFlags"]),
        # 
        'DwmSetIconicLivePreviewBitmap': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimStruct({"x": SimTypeInt(signed=True, label="Int32"), "y": SimTypeInt(signed=True, label="Int32")}, name="POINT", pack=False, align=None), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "hbmp", "pptClient", "dwSITFlags"]),
        # 
        'DwmInvalidateIconicBitmaps': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd"]),
        # 
        'DwmAttachMilContent': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd"]),
        # 
        'DwmDetachMilContent': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd"]),
        # 
        'DwmFlush': SimTypeFunction([], SimTypeInt(signed=True, label="Int32")),
        # 
        'DwmGetGraphicsStreamTransformHint': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimStruct({"S_11": SimTypeFloat(size=64), "S_12": SimTypeFloat(size=64), "S_21": SimTypeFloat(size=64), "S_22": SimTypeFloat(size=64), "DX": SimTypeFloat(size=64), "DY": SimTypeFloat(size=64)}, name="MilMatrix3x2D", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["uIndex", "pTransform"]),
        # 
        'DwmGetGraphicsStreamClient': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeBottom(label="Guid"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["uIndex", "pClientUuid"]),
        # 
        'DwmGetTransportAttributes': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int32"), offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int32"), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pfIsRemoting", "pfIsConnected", "pDwGeneration"]),
        # 
        'DwmTransitionOwnedWindow': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="DWMTRANSITION_OWNEDWINDOW_TARGET")], SimTypeInt(signed=True, label="Int32"), arg_names=["hwnd", "target"]),
        # 
        'DwmRenderGesture': SimTypeFunction([SimTypeInt(signed=False, label="GESTURE_TYPE"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), label="LPArray", offset=0), SimTypePointer(SimStruct({"x": SimTypeInt(signed=True, label="Int32"), "y": SimTypeInt(signed=True, label="Int32")}, name="POINT", pack=False, align=None), label="LPArray", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["gt", "cContacts", "pdwPointerID", "pPoints"]),
        # 
        'DwmTetherContact': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=True, label="Int32"), SimStruct({"x": SimTypeInt(signed=True, label="Int32"), "y": SimTypeInt(signed=True, label="Int32")}, name="POINT", pack=False, align=None)], SimTypeInt(signed=True, label="Int32"), arg_names=["dwPointerID", "fEnable", "ptTether"]),
        # 
        'DwmShowContact': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="DWM_SHOWCONTACT")], SimTypeInt(signed=True, label="Int32"), arg_names=["dwPointerID", "eShowContact"]),
        # 
        'DwmGetUnmetTabRequirements': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=False, label="DWM_TAB_WINDOW_REQUIREMENTS"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["appWindow", "value"]),
    }

lib.set_prototypes(prototypes)



# pylint:disable=line-too-long
import logging

from ...sim_type import SimTypeFunction,     SimTypeShort, SimTypeInt, SimTypeLong, SimTypeLongLong, SimTypeDouble, SimTypeFloat,     SimTypePointer,     SimTypeChar,     SimStruct,     SimTypeFixedSizeArray,     SimTypeBottom,     SimUnion,     SimTypeBool
from ...calling_conventions import SimCCStdcall, SimCCMicrosoftAMD64
from .. import SIM_PROCEDURES as P
from . import SimLibrary


_l = logging.getLogger(name=__name__)


lib = SimLibrary()
lib.set_default_cc('X86', SimCCStdcall)
lib.set_default_cc('AMD64', SimCCMicrosoftAMD64)
lib.set_library_names("wtsapi32.dll")
prototypes = \
    {
        # 
        'WTSStopRemoteControlSession': SimTypeFunction([SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["LogonId"]),
        # 
        'WTSStartRemoteControlSessionW': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeChar(label="Byte"), SimTypeShort(signed=False, label="UInt16")], SimTypeInt(signed=True, label="Int32"), arg_names=["pTargetServerName", "TargetLogonId", "HotkeyVk", "HotkeyModifiers"]),
        # 
        'WTSStartRemoteControlSessionA': SimTypeFunction([SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeChar(label="Byte"), SimTypeShort(signed=False, label="UInt16")], SimTypeInt(signed=True, label="Int32"), arg_names=["pTargetServerName", "TargetLogonId", "HotkeyVk", "HotkeyModifiers"]),
        # 
        'WTSConnectSessionA': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["LogonId", "TargetLogonId", "pPassword", "bWait"]),
        # 
        'WTSConnectSessionW': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["LogonId", "TargetLogonId", "pPassword", "bWait"]),
        # 
        'WTSEnumerateServersW': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"pServerName": SimTypePointer(SimTypeChar(label="Char"), offset=0)}, name="WTS_SERVER_INFOW", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pDomainName", "Reserved", "Version", "ppServerInfo", "pCount"]),
        # 
        'WTSEnumerateServersA': SimTypeFunction([SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"pServerName": SimTypePointer(SimTypeChar(label="Byte"), offset=0)}, name="WTS_SERVER_INFOA", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pDomainName", "Reserved", "Version", "ppServerInfo", "pCount"]),
        # 
        'WTSOpenServerW': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0)], SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), arg_names=["pServerName"]),
        # 
        'WTSOpenServerA': SimTypeFunction([SimTypePointer(SimTypeChar(label="Byte"), offset=0)], SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), arg_names=["pServerName"]),
        # 
        'WTSOpenServerExW': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0)], SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), arg_names=["pServerName"]),
        # 
        'WTSOpenServerExA': SimTypeFunction([SimTypePointer(SimTypeChar(label="Byte"), offset=0)], SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), arg_names=["pServerName"]),
        # 
        'WTSCloseServer': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeBottom(label="Void"), arg_names=["hServer"]),
        # 
        'WTSEnumerateSessionsW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"SessionId": SimTypeInt(signed=False, label="UInt32"), "pWinStationName": SimTypePointer(SimTypeChar(label="Char"), offset=0), "State": SimTypeInt(signed=False, label="WTS_CONNECTSTATE_CLASS")}, name="WTS_SESSION_INFOW", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "Reserved", "Version", "ppSessionInfo", "pCount"]),
        # 
        'WTSEnumerateSessionsA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"SessionId": SimTypeInt(signed=False, label="UInt32"), "pWinStationName": SimTypePointer(SimTypeChar(label="Byte"), offset=0), "State": SimTypeInt(signed=False, label="WTS_CONNECTSTATE_CLASS")}, name="WTS_SESSION_INFOA", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "Reserved", "Version", "ppSessionInfo", "pCount"]),
        # 
        'WTSEnumerateSessionsExW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"ExecEnvId": SimTypeInt(signed=False, label="UInt32"), "State": SimTypeInt(signed=False, label="WTS_CONNECTSTATE_CLASS"), "SessionId": SimTypeInt(signed=False, label="UInt32"), "pSessionName": SimTypePointer(SimTypeChar(label="Char"), offset=0), "pHostName": SimTypePointer(SimTypeChar(label="Char"), offset=0), "pUserName": SimTypePointer(SimTypeChar(label="Char"), offset=0), "pDomainName": SimTypePointer(SimTypeChar(label="Char"), offset=0), "pFarmName": SimTypePointer(SimTypeChar(label="Char"), offset=0)}, name="WTS_SESSION_INFO_1W", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pLevel", "Filter", "ppSessionInfo", "pCount"]),
        # 
        'WTSEnumerateSessionsExA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"ExecEnvId": SimTypeInt(signed=False, label="UInt32"), "State": SimTypeInt(signed=False, label="WTS_CONNECTSTATE_CLASS"), "SessionId": SimTypeInt(signed=False, label="UInt32"), "pSessionName": SimTypePointer(SimTypeChar(label="Byte"), offset=0), "pHostName": SimTypePointer(SimTypeChar(label="Byte"), offset=0), "pUserName": SimTypePointer(SimTypeChar(label="Byte"), offset=0), "pDomainName": SimTypePointer(SimTypeChar(label="Byte"), offset=0), "pFarmName": SimTypePointer(SimTypeChar(label="Byte"), offset=0)}, name="WTS_SESSION_INFO_1A", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pLevel", "Filter", "ppSessionInfo", "pCount"]),
        # 
        'WTSEnumerateProcessesW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"SessionId": SimTypeInt(signed=False, label="UInt32"), "ProcessId": SimTypeInt(signed=False, label="UInt32"), "pProcessName": SimTypePointer(SimTypeChar(label="Char"), offset=0), "pUserSid": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)}, name="WTS_PROCESS_INFOW", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "Reserved", "Version", "ppProcessInfo", "pCount"]),
        # 
        'WTSEnumerateProcessesA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimStruct({"SessionId": SimTypeInt(signed=False, label="UInt32"), "ProcessId": SimTypeInt(signed=False, label="UInt32"), "pProcessName": SimTypePointer(SimTypeChar(label="Byte"), offset=0), "pUserSid": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)}, name="WTS_PROCESS_INFOA", pack=False, align=None), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "Reserved", "Version", "ppProcessInfo", "pCount"]),
        # 
        'WTSTerminateProcess': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "ProcessId", "ExitCode"]),
        # 
        'WTSQuerySessionInformationW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="WTS_INFO_CLASS"), SimTypePointer(SimTypePointer(SimTypeChar(label="Char"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "SessionId", "WTSInfoClass", "ppBuffer", "pBytesReturned"]),
        # 
        'WTSQuerySessionInformationA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="WTS_INFO_CLASS"), SimTypePointer(SimTypePointer(SimTypeChar(label="Byte"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "SessionId", "WTSInfoClass", "ppBuffer", "pBytesReturned"]),
        # 
        'WTSQueryUserConfigW': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="WTS_CONFIG_CLASS"), SimTypePointer(SimTypePointer(SimTypeChar(label="Char"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pServerName", "pUserName", "WTSConfigClass", "ppBuffer", "pBytesReturned"]),
        # 
        'WTSQueryUserConfigA': SimTypeFunction([SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="WTS_CONFIG_CLASS"), SimTypePointer(SimTypePointer(SimTypeChar(label="Byte"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pServerName", "pUserName", "WTSConfigClass", "ppBuffer", "pBytesReturned"]),
        # 
        'WTSSetUserConfigW': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="WTS_CONFIG_CLASS"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["pServerName", "pUserName", "WTSConfigClass", "pBuffer", "DataLength"]),
        # 
        'WTSSetUserConfigA': SimTypeFunction([SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="WTS_CONFIG_CLASS"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["pServerName", "pUserName", "WTSConfigClass", "pBuffer", "DataLength"]),
        # 
        'WTSSendMessageW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="MESSAGEBOX_STYLE"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="MESSAGEBOX_RESULT"), offset=0), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "SessionId", "pTitle", "TitleLength", "pMessage", "MessageLength", "Style", "Timeout", "pResponse", "bWait"]),
        # 
        'WTSSendMessageA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="MESSAGEBOX_STYLE"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="MESSAGEBOX_RESULT"), offset=0), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "SessionId", "pTitle", "TitleLength", "pMessage", "MessageLength", "Style", "Timeout", "pResponse", "bWait"]),
        # 
        'WTSDisconnectSession': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "SessionId", "bWait"]),
        # 
        'WTSLogoffSession': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "SessionId", "bWait"]),
        # 
        'WTSShutdownSystem': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "ShutdownFlag"]),
        # 
        'WTSWaitSystemEvent': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "EventMask", "pEventFlags"]),
        # 
        'WTSVirtualChannelOpen': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0)], SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), arg_names=["hServer", "SessionId", "pVirtualName"]),
        # 
        'WTSVirtualChannelOpenEx': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), arg_names=["SessionId", "pVirtualName", "flags"]),
        # 
        'WTSVirtualChannelClose': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hChannelHandle"]),
        # 
        'WTSVirtualChannelRead': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hChannelHandle", "TimeOut", "Buffer", "BufferSize", "pBytesRead"]),
        # 
        'WTSVirtualChannelWrite': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hChannelHandle", "Buffer", "Length", "pBytesWritten"]),
        # 
        'WTSVirtualChannelPurgeInput': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hChannelHandle"]),
        # 
        'WTSVirtualChannelPurgeOutput': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hChannelHandle"]),
        # 
        'WTSVirtualChannelQuery': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="WTS_VIRTUAL_CLASS"), SimTypePointer(SimTypePointer(SimTypeBottom(label="Void"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hChannelHandle", "param1", "ppBuffer", "pBytesReturned"]),
        # 
        'WTSFreeMemory': SimTypeFunction([SimTypePointer(SimTypeBottom(label="Void"), offset=0)], SimTypeBottom(label="Void"), arg_names=["pMemory"]),
        # 
        'WTSRegisterSessionNotification': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hWnd", "dwFlags"]),
        # 
        'WTSUnRegisterSessionNotification': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hWnd"]),
        # 
        'WTSRegisterSessionNotificationEx': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "hWnd", "dwFlags"]),
        # 
        'WTSUnRegisterSessionNotificationEx': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "hWnd"]),
        # 
        'WTSQueryUserToken': SimTypeFunction([SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["SessionId", "phToken"]),
        # 
        'WTSFreeMemoryExW': SimTypeFunction([SimTypeInt(signed=False, label="WTS_TYPE_CLASS"), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["WTSTypeClass", "pMemory", "NumberOfEntries"]),
        # 
        'WTSFreeMemoryExA': SimTypeFunction([SimTypeInt(signed=False, label="WTS_TYPE_CLASS"), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["WTSTypeClass", "pMemory", "NumberOfEntries"]),
        # 
        'WTSEnumerateProcessesExW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimTypeChar(label="Char"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pLevel", "SessionId", "ppProcessInfo", "pCount"]),
        # 
        'WTSEnumerateProcessesExA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimTypeChar(label="Byte"), offset=0), offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pLevel", "SessionId", "ppProcessInfo", "pCount"]),
        # 
        'WTSEnumerateListenersW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimTypeShort(signed=False, label="UInt16"), offset=0), label="LPArray", offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListeners", "pCount"]),
        # 
        'WTSEnumerateListenersA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypePointer(SimTypeChar(label="SByte"), offset=0), label="LPArray", offset=0), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListeners", "pCount"]),
        # 
        'WTSQueryListenerConfigW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypePointer(SimStruct({"version": SimTypeInt(signed=False, label="UInt32"), "fEnableListener": SimTypeInt(signed=False, label="UInt32"), "MaxConnectionCount": SimTypeInt(signed=False, label="UInt32"), "fPromptForPassword": SimTypeInt(signed=False, label="UInt32"), "fInheritColorDepth": SimTypeInt(signed=False, label="UInt32"), "ColorDepth": SimTypeInt(signed=False, label="UInt32"), "fInheritBrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "BrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "fDisablePrinterRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDriveRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableComPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableLPTPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableClipboardRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableAudioRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisablePNPRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDefaultMainClientPrinter": SimTypeInt(signed=False, label="UInt32"), "LanAdapter": SimTypeInt(signed=False, label="UInt32"), "PortNumber": SimTypeInt(signed=False, label="UInt32"), "fInheritShadowSettings": SimTypeInt(signed=False, label="UInt32"), "ShadowSettings": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsConnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsDisconnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsIdle": SimTypeInt(signed=False, label="UInt32"), "SecurityLayer": SimTypeInt(signed=False, label="UInt32"), "MinEncryptionLevel": SimTypeInt(signed=False, label="UInt32"), "UserAuthentication": SimTypeInt(signed=False, label="UInt32"), "Comment": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 61), "LogonUserName": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 21), "LogonDomain": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 18), "WorkDirectory": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 261), "InitialProgram": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 261)}, name="WTSLISTENERCONFIGW", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "pBuffer"]),
        # 
        'WTSQueryListenerConfigA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypePointer(SimStruct({"version": SimTypeInt(signed=False, label="UInt32"), "fEnableListener": SimTypeInt(signed=False, label="UInt32"), "MaxConnectionCount": SimTypeInt(signed=False, label="UInt32"), "fPromptForPassword": SimTypeInt(signed=False, label="UInt32"), "fInheritColorDepth": SimTypeInt(signed=False, label="UInt32"), "ColorDepth": SimTypeInt(signed=False, label="UInt32"), "fInheritBrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "BrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "fDisablePrinterRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDriveRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableComPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableLPTPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableClipboardRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableAudioRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisablePNPRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDefaultMainClientPrinter": SimTypeInt(signed=False, label="UInt32"), "LanAdapter": SimTypeInt(signed=False, label="UInt32"), "PortNumber": SimTypeInt(signed=False, label="UInt32"), "fInheritShadowSettings": SimTypeInt(signed=False, label="UInt32"), "ShadowSettings": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsConnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsDisconnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsIdle": SimTypeInt(signed=False, label="UInt32"), "SecurityLayer": SimTypeInt(signed=False, label="UInt32"), "MinEncryptionLevel": SimTypeInt(signed=False, label="UInt32"), "UserAuthentication": SimTypeInt(signed=False, label="UInt32"), "Comment": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 61), "LogonUserName": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 21), "LogonDomain": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 18), "WorkDirectory": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 261), "InitialProgram": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 261)}, name="WTSLISTENERCONFIGA", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "pBuffer"]),
        # 
        'WTSCreateListenerW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypePointer(SimStruct({"version": SimTypeInt(signed=False, label="UInt32"), "fEnableListener": SimTypeInt(signed=False, label="UInt32"), "MaxConnectionCount": SimTypeInt(signed=False, label="UInt32"), "fPromptForPassword": SimTypeInt(signed=False, label="UInt32"), "fInheritColorDepth": SimTypeInt(signed=False, label="UInt32"), "ColorDepth": SimTypeInt(signed=False, label="UInt32"), "fInheritBrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "BrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "fDisablePrinterRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDriveRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableComPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableLPTPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableClipboardRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableAudioRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisablePNPRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDefaultMainClientPrinter": SimTypeInt(signed=False, label="UInt32"), "LanAdapter": SimTypeInt(signed=False, label="UInt32"), "PortNumber": SimTypeInt(signed=False, label="UInt32"), "fInheritShadowSettings": SimTypeInt(signed=False, label="UInt32"), "ShadowSettings": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsConnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsDisconnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsIdle": SimTypeInt(signed=False, label="UInt32"), "SecurityLayer": SimTypeInt(signed=False, label="UInt32"), "MinEncryptionLevel": SimTypeInt(signed=False, label="UInt32"), "UserAuthentication": SimTypeInt(signed=False, label="UInt32"), "Comment": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 61), "LogonUserName": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 21), "LogonDomain": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 18), "WorkDirectory": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 261), "InitialProgram": SimTypeFixedSizeArray(SimTypeChar(label="Char"), 261)}, name="WTSLISTENERCONFIGW", pack=False, align=None), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "pBuffer", "flag"]),
        # 
        'WTSCreateListenerA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypePointer(SimStruct({"version": SimTypeInt(signed=False, label="UInt32"), "fEnableListener": SimTypeInt(signed=False, label="UInt32"), "MaxConnectionCount": SimTypeInt(signed=False, label="UInt32"), "fPromptForPassword": SimTypeInt(signed=False, label="UInt32"), "fInheritColorDepth": SimTypeInt(signed=False, label="UInt32"), "ColorDepth": SimTypeInt(signed=False, label="UInt32"), "fInheritBrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "BrokenTimeoutSettings": SimTypeInt(signed=False, label="UInt32"), "fDisablePrinterRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDriveRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableComPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableLPTPortRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableClipboardRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableAudioRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisablePNPRedirection": SimTypeInt(signed=False, label="UInt32"), "fDisableDefaultMainClientPrinter": SimTypeInt(signed=False, label="UInt32"), "LanAdapter": SimTypeInt(signed=False, label="UInt32"), "PortNumber": SimTypeInt(signed=False, label="UInt32"), "fInheritShadowSettings": SimTypeInt(signed=False, label="UInt32"), "ShadowSettings": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsConnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsDisconnection": SimTypeInt(signed=False, label="UInt32"), "TimeoutSettingsIdle": SimTypeInt(signed=False, label="UInt32"), "SecurityLayer": SimTypeInt(signed=False, label="UInt32"), "MinEncryptionLevel": SimTypeInt(signed=False, label="UInt32"), "UserAuthentication": SimTypeInt(signed=False, label="UInt32"), "Comment": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 61), "LogonUserName": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 21), "LogonDomain": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 18), "WorkDirectory": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 261), "InitialProgram": SimTypeFixedSizeArray(SimTypeBottom(label="CHAR"), 261)}, name="WTSLISTENERCONFIGA", pack=False, align=None), offset=0), SimTypeInt(signed=False, label="UInt32")], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "pBuffer", "flag"]),
        # 
        'WTSSetListenerSecurityW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimStruct({"Revision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "Control": SimTypeShort(signed=False, label="UInt16"), "Owner": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Group": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Sacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0), "Dacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0)}, name="SECURITY_DESCRIPTOR", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "SecurityInformation", "pSecurityDescriptor"]),
        # 
        'WTSSetListenerSecurityA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimStruct({"Revision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "Control": SimTypeShort(signed=False, label="UInt16"), "Owner": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Group": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Sacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0), "Dacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0)}, name="SECURITY_DESCRIPTOR", pack=False, align=None), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "SecurityInformation", "pSecurityDescriptor"]),
        # 
        'WTSGetListenerSecurityW': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimStruct({"Revision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "Control": SimTypeShort(signed=False, label="UInt16"), "Owner": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Group": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Sacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0), "Dacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0)}, name="SECURITY_DESCRIPTOR", pack=False, align=None), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "SecurityInformation", "pSecurityDescriptor", "nLength", "lpnLengthNeeded"]),
        # 
        'WTSGetListenerSecurityA': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypePointer(SimTypeBottom(label="Void"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimStruct({"Revision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "Control": SimTypeShort(signed=False, label="UInt16"), "Owner": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Group": SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), "Sacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0), "Dacl": SimTypePointer(SimStruct({"AclRevision": SimTypeChar(label="Byte"), "Sbz1": SimTypeChar(label="Byte"), "AclSize": SimTypeShort(signed=False, label="UInt16"), "AceCount": SimTypeShort(signed=False, label="UInt16"), "Sbz2": SimTypeShort(signed=False, label="UInt16")}, name="ACL", pack=False, align=None), offset=0)}, name="SECURITY_DESCRIPTOR", pack=False, align=None), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["hServer", "pReserved", "Reserved", "pListenerName", "SecurityInformation", "pSecurityDescriptor", "nLength", "lpnLengthNeeded"]),
        # 
        'WTSEnableChildSessions': SimTypeFunction([SimTypeInt(signed=True, label="Int32")], SimTypeInt(signed=True, label="Int32"), arg_names=["bEnable"]),
        # 
        'WTSIsChildSessionsEnabled': SimTypeFunction([SimTypePointer(SimTypeInt(signed=True, label="Int32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pbEnabled"]),
        # 
        'WTSGetChildSessionId': SimTypeFunction([SimTypePointer(SimTypeInt(signed=False, label="UInt32"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pSessionId"]),
        # 
        'WTSSetRenderHint': SimTypeFunction([SimTypePointer(SimTypeLongLong(signed=False, label="UInt64"), offset=0), SimTypePointer(SimTypeInt(signed=True, label="Int"), label="IntPtr", offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeChar(label="Byte"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["pRenderHintID", "hwndOwner", "renderHintType", "cbHintDataLength", "pHintData"]),
    }

lib.set_prototypes(prototypes)
